@@ -12,6 +12,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from datetime import datetime
 import json
 import logging
 import os
@@ -29,7 +30,7 @@ from mistral_lib import actions
 from oslo_concurrency import processutils
 
 from tripleo_common.actions import base
-from tripleo_common.inventory import TripleoInventory
+from tripleo_common import inventory
 
 LOG = logging.getLogger(__name__)
 
@@ -47,8 +48,14 @@ def write_default_ansible_cfg(work_dir,
     config.read(ansible_config_path)
 
     config.set('defaults', 'retry_files_enabled', 'False')
-    config.set('defaults', 'log_path',
-               os.path.join(work_dir, 'ansible.log'))
+
+    log_path = os.path.join(work_dir, 'ansible.log')
+    config.set('defaults', 'log_path', log_path)
+    if os.path.exists(log_path):
+        new_path = (log_path + '-' +
+                    datetime.now().strftime("%Y-%m-%dT%H:%M:%S"))
+        os.rename(log_path, new_path)
+
     config.set('defaults', 'forks', '25')
     config.set('defaults', 'timeout', '30')
     config.set('defaults', 'gather_timeout', '30')
@@ -533,9 +540,6 @@ class AnsiblePlaybookAction(base.TripleOAction):
                     'OS_AUTH_TOKEN': security_ctx.auth_token,
                     'OS_PROJECT_NAME': security_ctx.project_name})
 
-            if self.command_timeout:
-                command = ['timeout', self.command_timeout] + command
-
             command = [str(c) for c in command]
 
             if self.reproduce_command:
@@ -553,6 +557,9 @@ class AnsiblePlaybookAction(base.TripleOAction):
 
                 os.chmod(command_path, 0o750)
 
+            if self.command_timeout:
+                command = ['timeout', str(self.command_timeout)] + command
+
             if self.queue_name:
                 zaqar = self.get_messaging_client(context)
                 queue = zaqar.queue(self.queue_name)
@@ -606,6 +613,8 @@ class AnsibleGenerateInventoryAction(base.TripleOAction):
         self._kwargs_for_run = kwargs
         self.ansible_ssh_user = self._kwargs_for_run.pop(
             'ansible_ssh_user', 'tripleo-admin')
+        self.undercloud_key_file = self._kwargs_for_run.pop(
+            'undercloud_key_file', None)
         self.ansible_python_interpreter = self._kwargs_for_run.pop(
             'ansible_python_interpreter', None)
         self._work_dir = self._kwargs_for_run.pop(
@@ -627,7 +636,7 @@ class AnsibleGenerateInventoryAction(base.TripleOAction):
         inventory_path = os.path.join(
             self.work_dir, 'tripleo-ansible-inventory.yaml')
 
-        inventory = TripleoInventory(
+        inv = inventory.TripleoInventory(
             session=self.get_session(context, 'heat'),
             hclient=self.get_orchestration_client(context),
             auth_url=context.security.auth_uri,
@@ -635,9 +644,11 @@ class AnsibleGenerateInventoryAction(base.TripleOAction):
             project_name=context.security.project_name,
             username=context.security.user_name,
             ansible_ssh_user=self.ansible_ssh_user,
+            undercloud_key_file=self.undercloud_key_file,
+            undercloud_connection=inventory.UNDERCLOUD_CONNECTION_SSH,
             ansible_python_interpreter=self.ansible_python_interpreter,
             plan_name=self.plan_name,
             host_network=self.ssh_network)
 
-        inventory.write_static_inventory(inventory_path)
+        inv.write_static_inventory(inventory_path)
         return inventory_path
