@@ -115,6 +115,7 @@ PASSWORD_PARAMETER_NAMES = (
     'NovaPassword',
     'NovajoinPassword',
     'MigrationSshKey',
+    'OctaviaServerCertsKeyPassphrase',
     'OctaviaCaKeyPassphrase',
     'OctaviaHeartbeatKey',
     'OctaviaPassword',
@@ -205,3 +206,5 @@ DEPLOYMENT_STATUS_FILE = 'deployment_status.yaml'
 MISTRAL_WORK_DIR = '/var/lib/mistral'
 
 EXCLUSIVE_NEUTRON_DRIVERS = ['ovn', 'openvswitch']
+
+UPGRADE_STEPS_MAX = 6
