@@ -17,12 +17,18 @@
 import abc
 import logging
 import os
+import shlex
 import six
 import subprocess
 import sys
 
 from tripleo_common.image.exception import ImageBuilderException
 
+if sys.version_info[0] < 3:
+    import codecs
+    _open = open
+    open = codecs.open
+
 
 @six.add_metaclass(abc.ABCMeta)
 class ImageBuilder(object):
@@ -75,7 +81,6 @@ class DibImageBuilder(ImageBuilder):
         if elements_path is None:
             env['ELEMENTS_PATH'] = os.pathsep.join([
                 "/usr/share/tripleo-puppet-elements",
-                "/usr/share/instack-undercloud",
                 '/usr/share/tripleo-image-elements',
             ])
             os.environ.update(env)
@@ -89,7 +94,7 @@ class DibImageBuilder(ImageBuilder):
 
         if options:
             for option in options:
-                cmd.extend(option.split(' '))
+                cmd.extend(shlex.split(option))
 
         skip_base = extra_options.get('skip_base', False)
         if skip_base:
@@ -116,7 +121,7 @@ class DibImageBuilder(ImageBuilder):
         process = subprocess.Popen(cmd,
                                    stdout=subprocess.PIPE,
                                    stderr=subprocess.STDOUT)
-        with open(log_file, 'w') as f:
+        with open(log_file, 'w', encoding='utf-8') as f:
             while True:
                 line = process.stdout.readline()
                 try:
