@@ -128,34 +128,47 @@ class TestConfig(base.TestCase):
         self.tmp_dir = self.useFixture(fixtures.TempDir()).path
         fake_role = [role for role in
                      fakes.FAKE_STACK['outputs'][1]['output_value']]
-        expected_tasks = {'FakeController': [{'name': 'Stop fake service',
-                                              'service': 'name=fake '
-                                              'state=stopped',
-                                              'when': 'step|int == 1'}],
-                          'FakeCompute': [{'name': 'Stop fake service',
-                                           'service':
-                                           'name=fake state=stopped',
-                                           'when': ['nova_api_enabled.rc == 0',
-                                                    'httpd_enabled.rc != 0',
-                                                    'step|int == 1']},
-                                          {'name': 'Stop nova-'
-                                           'compute service',
-                                           'service':
-                                           'name=openstack-nova-'
-                                           'compute state=stopped',
-                                           'when': [
-                                               'nova_compute_enabled.rc == 0',
-                                               'step|int == 2', 'existing',
-                                               'list']}]}
+        expected_tasks = {'FakeController': {0: [],
+                                             1: [{'name': 'Stop fake service',
+                                                  'service': 'name=fake '
+                                                  'state=stopped',
+                                                  'when': 'step|int == 1'}],
+                                             2: [],
+                                             3: [],
+                                             4: [],
+                                             5: []},
+                          'FakeCompute': {0: [],
+                                          1: [{'name': 'Stop fake service',
+                                               'service': 'name=fake '
+                                               'state=stopped',
+                                               'when': ['nova_api_enabled.rc'
+                                                        ' == 0',
+                                                        'httpd_enabled.rc'
+                                                        ' != 0',
+                                                        'step|int == 1']}],
+                                          2: [{'name': 'Stop nova-compute '
+                                               'service',
+                                               'service': 'name=openstack-'
+                                               'nova-compute state=stopped',
+                                               'when': ['nova_compute_'
+                                                        'enabled.rc == 0',
+                                                        'step|int == 2',
+                                                        'existing',
+                                                        'list']}],
+                                          3: [],
+                                          4: [],
+                                          5: []}}
         for role in fake_role:
             filedir = os.path.join(self.tmp_dir, role)
             os.makedirs(filedir)
-            filepath = os.path.join(filedir, "upgrade_tasks_playbook.yaml")
-            playbook_tasks = self.config._write_playbook_get_tasks(
-                fakes.FAKE_STACK['outputs'][1]['output_value'][role]
-                ['upgrade_tasks'], role, filepath)
-            self.assertTrue(os.path.isfile(filepath))
-            self.assertEqual(expected_tasks[role], playbook_tasks)
+            for step in range(constants.UPGRADE_STEPS_MAX):
+                filepath = os.path.join(filedir, "upgrade_tasks_step%s.yaml"
+                                        % step)
+                playbook_tasks = self.config._write_tasks_per_step(
+                    fakes.FAKE_STACK['outputs'][1]['output_value'][role]
+                    ['upgrade_tasks'], role, filepath, step)
+                self.assertTrue(os.path.isfile(filepath))
+                self.assertEqual(expected_tasks[role][step], playbook_tasks)
 
     def test_get_server_names(self):
         heat = mock.MagicMock()
@@ -445,9 +458,17 @@ class TestConfig(base.TestCase):
         with warnings.catch_warnings(record=True) as w:
             self.config.download_config(stack, self.tmp_dir)
             mock_git_init.assert_called_once_with(self.tmp_dir)
-            self.assertEqual(1, len(w))
-            assert issubclass(w[-1].category, DeprecationWarning)
-            assert "group:os-apply-config is deprecated" in str(w[-1].message)
+            # check that we got at least one of the warnings that we expected
+            # to throw
+            self.assertGreaterEqual(len(w), 1)
+            self.assertGreaterEqual(len([x for x in w
+                                         if issubclass(x.category,
+                                                       DeprecationWarning)]),
+                                    1)
+            self.assertGreaterEqual(len([x for x in w
+                                         if "group:os-apply-config"
+                                         in str(x.message)]),
+                                    1)
 
     @patch.object(ooo_config.Config, 'initialize_git_repo')
     @patch('tripleo_common.utils.config.Config.get_deployment_resource_id')
